pub struct ExecApprovalRequestEvent {Show 14 fields
pub call_id: String,
pub approval_id: Option<String>,
pub turn_id: String,
pub environment_id: Option<String>,
pub started_at_ms: i64,
pub command: Vec<String>,
pub cwd: AbsolutePathBuf,
pub reason: Option<String>,
pub network_approval_context: Option<NetworkApprovalContext>,
pub proposed_execpolicy_amendment: Option<ExecPolicyAmendment>,
pub proposed_network_policy_amendments: Option<Vec<NetworkPolicyAmendment>>,
pub additional_permissions: Option<AdditionalPermissionProfile>,
pub available_decisions: Option<Vec<ReviewDecision>>,
pub parsed_cmd: Vec<ParsedCommand>,
}Fields
call_id: StringIdentifier for the associated command execution item.
approval_id: Option<String>Identifier for this specific approval callback.
When absent, the approval is for the command item itself (call_id).
This is present for subcommand approvals (via execve intercept).
turn_id: StringTurn ID that this command belongs to.
Uses #[serde(default)] for backwards compatibility.
environment_id: Option<String>Environment in which the command will run.
started_at_ms: i64command: Vec<String>The command to be executed.
cwd: AbsolutePathBufThe command’s working directory.
reason: Option<String>Optional human-readable reason for the approval (e.g. retry without sandbox).
network_approval_context: Option<NetworkApprovalContext>Optional network context for a blocked request that can be approved.
proposed_execpolicy_amendment: Option<ExecPolicyAmendment>Proposed execpolicy amendment that can be applied to allow future runs.
proposed_network_policy_amendments: Option<Vec<NetworkPolicyAmendment>>Proposed network policy amendments (for example allow/deny this host in future).
additional_permissions: Option<AdditionalPermissionProfile>Optional additional filesystem permissions requested for this command.
available_decisions: Option<Vec<ReviewDecision>>Ordered list of decisions the client may present for this prompt.
When absent, clients should derive the legacy default set from the other fields on this request.
parsed_cmd: Vec<ParsedCommand>Implementations
Sourceimpl ExecApprovalRequestEvent
impl ExecApprovalRequestEvent
pub fn effective_approval_id(&self) -> String
pub fn effective_available_decisions(&self) -> Vec<ReviewDecision>
pub fn default_available_decisions( network_approval_context: Option<&NetworkApprovalContext>, proposed_execpolicy_amendment: Option<&ExecPolicyAmendment>, proposed_network_policy_amendments: Option<&[NetworkPolicyAmendment]>, additional_permissions: Option<&AdditionalPermissionProfile>, ) -> Vec<ReviewDecision>