pub struct ShellEnvironmentPolicy {
pub inherit: ShellEnvironmentPolicyInherit,
pub ignore_default_excludes: bool,
pub exclude: Vec<EnvironmentVariablePattern>,
pub set: HashMap<String, String>,
pub include_only: Vec<EnvironmentVariablePattern>,
pub use_profile: bool,
}Expand description
Deriving the env based on this policy works as follows:
- Create an initial map based on the
inheritpolicy. - If
ignore_default_excludesis false, filter the map using the default exclude pattern(s), which are:"*KEY*","*SECRET*", and"*TOKEN*". - If
excludeis not empty, filter the map using the provided patterns. - Insert any entries from
r#setinto the map. - If non-empty, filter the map using the
include_onlypatterns.
Fields
inherit: ShellEnvironmentPolicyInheritStarting point when building the environment.
ignore_default_excludes: boolTrue to skip the check to exclude default environment variables that contain “KEY”, “SECRET”, or “TOKEN” in their name. Defaults to true.
exclude: Vec<EnvironmentVariablePattern>Environment variable names to exclude from the environment.
set: HashMap<String, String>(key, value) pairs to insert in the environment.
include_only: Vec<EnvironmentVariablePattern>Environment variable names to retain in the environment.
use_profile: boolIf true, the shell profile will be used to run the command.