Module mcp

Module mcp 

Types used when representing Model Context Protocol (MCP) values inside the Codex protocol.

We intentionally keep these types TS/JSON-schema friendly (via ts-rs and schemars) so they can be embedded in Codex’s own protocol structures.

Structs

CallToolResult
The server’s response to a tool call.
McpServerInfo
Presentation metadata advertised by an initialized MCP server.
Resource
A known resource that the server is capable of reading.
ResourceTemplate
A template description for resources available on the server.
Tool
Definition for a tool the client can call.

Enums

RequestId
ID of a request, which can be either a string or an integer.
ResourceContent
Contents returned when reading a resource from an MCP server.