pub struct SessionConfiguredEvent {Show 18 fields
pub session_id: SessionId,
pub thread_id: ThreadId,
pub forked_from_id: Option<ThreadId>,
pub parent_thread_id: Option<ThreadId>,
pub thread_source: Option<ThreadSource>,
pub thread_name: Option<String>,
pub model: String,
pub model_provider_id: String,
pub service_tier: Option<String>,
pub approval_policy: AskForApproval,
pub approvals_reviewer: ApprovalsReviewer,
pub permission_profile: PermissionProfile,
pub active_permission_profile: Option<ActivePermissionProfile>,
pub cwd: AbsolutePathBuf,
pub reasoning_effort: Option<ReasoningEffort>,
pub initial_messages: Option<Vec<EventMsg>>,
pub network_proxy: Option<SessionNetworkProxyRuntime>,
pub rollout_path: Option<PathBuf>,
}Fields
session_id: SessionIdthread_id: ThreadIdforked_from_id: Option<ThreadId>parent_thread_id: Option<ThreadId>thread_source: Option<ThreadSource>Optional analytics source classification for this thread.
thread_name: Option<String>Optional user-facing thread name (may be unset).
model: StringTell the client what model is being queried.
model_provider_id: Stringservice_tier: Option<String>approval_policy: AskForApprovalWhen to escalate for approval for execution
approvals_reviewer: ApprovalsReviewerConfigures who approval requests are routed to for review once they have been escalated. This does not disable separate safety checks such as ARC.
permission_profile: PermissionProfileCanonical effective permissions for commands executed in the session.
active_permission_profile: Option<ActivePermissionProfile>Named or implicit built-in profile that produced permission_profile,
when known.
cwd: AbsolutePathBufWorking directory that should be treated as the root of the session.
reasoning_effort: Option<ReasoningEffort>The effort the model is putting into reasoning about the user’s request.
initial_messages: Option<Vec<EventMsg>>Optional initial messages (as events) for resumed sessions. When present, UIs can use these to seed the history.
network_proxy: Option<SessionNetworkProxyRuntime>Runtime proxy bind addresses, when the managed proxy was started for this session.
rollout_path: Option<PathBuf>Path in which the rollout is stored. Can be None for ephemeral threads