pub struct Submission {
pub id: String,
pub op: Op,
pub client_user_message_id: Option<String>,
pub trace: Option<W3cTraceContext>,
}Expand description
Submission Queue Entry - requests from user
Fields
id: StringUnique id for this Submission to correlate with Events
op: OpPayload
client_user_message_id: Option<String>Client-provided id for the user message represented by Op::UserInput.
trace: Option<W3cTraceContext>Optional W3C trace carrier propagated across async submission handoffs.