WritableRoot

Struct WritableRoot 

pub struct WritableRoot {
    pub root: AbsolutePathBuf,
    pub read_only_subpaths: Vec<AbsolutePathBuf>,
    pub protected_metadata_names: Vec<String>,
}
A writable root path accompanied by a list of subpaths that should remain read‑only even when the root is writable. This is primarily used to ensure that folders containing files that could be modified to escalate the privileges of the agent (e.g. .codex, .git, notably .git/hooks) under a writable root are not modified by the agent.

Fields

root: AbsolutePathBufread_only_subpaths: Vec<AbsolutePathBuf>

By construction, these subpaths are all under root.

protected_metadata_names: Vec<String>

Workspace metadata path names that must not be created or replaced under root unless the policy grants an explicit write rule for that metadata path.

Implementations