HasLegacyEvent

Trait HasLegacyEvent 

pub trait HasLegacyEvent {
    // Required method
    fn as_legacy_events(&self, show_raw_agent_reasoning: bool) -> Vec<EventMsg>;
}
Converts canonical item lifecycle events back into the legacy raw event stream used by compatibility consumers that have not migrated to TurnItem.

Required Methods

fn as_legacy_events(&self, show_raw_agent_reasoning: bool) -> Vec<EventMsg>

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors