Types used when representing Model Context Protocol (MCP) values inside the Codex protocol.
We intentionally keep these types TS/JSON-schema friendly (via ts-rs and
schemars) so they can be embedded in Codex’s own protocol structures.
Structs
- Call
Tool Result - The server’s response to a tool call.
- McpServer
Info - Presentation metadata advertised by an initialized MCP server.
- Resource
- A known resource that the server is capable of reading.
- Resource
Template - A template description for resources available on the server.
- Tool
- Definition for a tool the client can call.
Enums
- Request
Id - ID of a request, which can be either a string or an integer.
- Resource
Content - Contents returned when reading a resource from an MCP server.