Structs
- File
System Sandbox Entry - File
System Sandbox Policy - Read
Deny Matcher - Runtime matcher for read-deny entries in a filesystem sandbox policy.
Enums
- File
System Access Mode - Access mode for a filesystem entry.
- File
System Path - File
System Sandbox Entry Missing Path Behavior - File
System Sandbox Kind - File
System Special Path - Network
Sandbox Policy
Constants
- PROTECTED_
METADATA_ PATH_ NAMES - Top-level workspace metadata paths that stay protected under writable roots.
Functions
- forbidden_
agent_ metadata_ write - Returns the protected workspace metadata name when an agent write to
pathshould be blocked before execution. - is_
protected_ metadata_ name - Returns true when a path basename is one of the protected workspace metadata names.
- project_
roots_ glob_ pattern